@@ -40,15 +40,13 @@ from ansible import constants as C
 from ansible.cli import CLI
 from ansible.errors import AnsibleError
 from ansible.executor.task_queue_manager import TaskQueueManager
-from ansible.inventory import Inventory
 from ansible.module_utils._text import to_native, to_text
-from ansible.parsing.dataloader import DataLoader
+from ansible.module_utils.parsing.convert_bool import boolean
 from ansible.parsing.splitter import parse_kv
 from ansible.playbook.play import Play
-from ansible.plugins import module_loader
-from ansible.utils import module_docs
+from ansible.plugins.loader import module_loader
+from ansible.utils import plugin_docs
 from ansible.utils.color import stringc
-from ansible.vars import VariableManager
 
 try:
     from __main__ import display
@@ -58,8 +56,11 @@ except ImportError:
 
 
 class ConsoleCLI(CLI, cmd.Cmd):
+    ''' a REPL that allows for running ad-hoc tasks against a chosen inventory (based on dominis' ansible-shell).'''
 
     modules = []
+    ARGUMENTS = {'host-pattern': 'A name of a group in the inventory, a shell-like glob '
+                                 'selecting hosts in inventory or any combination of the two separated by commas.'}
 
     def __init__(self, args):
 
@@ -79,7 +80,7 @@ class ConsoleCLI(CLI, cmd.Cmd):
 
     def parse(self):
         self.parser = CLI.base_parser(
-            usage='%prog <host-pattern> [options]',
+            usage='%prog [<host-pattern>] [options]',
             runas_opts=True,
             inventory_opts=True,
             connect_opts=True,
@@ -87,11 +88,13 @@ class ConsoleCLI(CLI, cmd.Cmd):
             vault_opts=True,
             fork_opts=True,
             module_opts=True,
+            desc="REPL console for executing Ansible tasks.",
+            epilog="This is not a live session/connection, each task executes in the background and returns it's results."
         )
 
         # options unique to shell
         self.parser.add_option('--step', dest='step', action='store_true',
-            help="one-step-at-a-time: confirm each task before running")
+                               help="one-step-at-a-time: confirm each task before running")
 
         self.parser.set_defaults(cwd='*')
 
@@ -123,9 +126,10 @@ class ConsoleCLI(CLI, cmd.Cmd):
 
     def list_modules(self):
         modules = set()
-        if self.options.module_path is not None:
-            for i in self.options.module_path.split(os.pathsep):
-                module_loader.add_directory(i)
+        if self.options.module_path:
+            for path in self.options.module_path:
+                if path:
+                    module_loader.add_directory(path)
 
         module_paths = module_loader._get_paths()
         for path in module_paths:
@@ -148,7 +152,7 @@ class ConsoleCLI(CLI, cmd.Cmd):
                 elif module in C.IGNORE_FILES:
                     continue
                 elif module.startswith('_'):
-                    fullpath = '/'.join([path,module])
+                    fullpath = '/'.join([path, module])
                     if os.path.islink(fullpath):  # avoids aliases
                         continue
                     module = module.replace('_', '', 1)
@@ -182,10 +186,10 @@ class ConsoleCLI(CLI, cmd.Cmd):
         try:
             check_raw = self.options.module_name in ('command', 'shell', 'script', 'raw')
             play_ds = dict(
-                name = "Ansible Shell",
-                hosts = self.options.cwd,
-                gather_facts = 'no',
-                tasks = [ dict(action=dict(module=module, args=parse_kv(module_args, check_raw=check_raw)))]
+                name="Ansible Shell",
+                hosts=self.options.cwd,
+                gather_facts='no',
+                tasks=[dict(action=dict(module=module, args=parse_kv(module_args, check_raw=check_raw)))]
             )
             play = Play().load(play_ds, variable_manager=self.variable_manager, loader=self.loader)
         except Exception as e:
@@ -272,11 +276,6 @@ class ConsoleCLI(CLI, cmd.Cmd):
         """
         if not arg:
             self.options.cwd = '*'
-        elif arg == '..':
-            try:
-                self.options.cwd = self.inventory.groups_for_host(self.options.cwd)[1].name
-            except Exception:
-                self.options.cwd = ''
         elif arg in '/*':
             self.options.cwd = 'all'
         elif self.inventory.get_hosts(arg):
@@ -298,7 +297,7 @@ class ConsoleCLI(CLI, cmd.Cmd):
     def do_become(self, arg):
         """Toggle whether plays run with become"""
         if arg:
-            self.options.become = C.mk_boolean(arg)
+            self.options.become = boolean(arg, strict=False)
             display.v("become changed to %s" % self.options.become)
             self.set_prompt()
         else:
@@ -332,7 +331,7 @@ class ConsoleCLI(CLI, cmd.Cmd):
     def do_check(self, arg):
         """Toggle whether plays run with check mode"""
         if arg:
-            self.options.check = C.mk_boolean(arg)
+            self.options.check = boolean(arg, strict=False)
             display.v("check mode changed to %s" % self.options.check)
         else:
             display.display("Please specify check mode value, e.g. `check yes`")
@@ -340,7 +339,7 @@ class ConsoleCLI(CLI, cmd.Cmd):
     def do_diff(self, arg):
         """Toggle whether plays run with diff"""
         if arg:
-            self.options.diff = C.mk_boolean(arg)
+            self.options.diff = boolean(arg, strict=False)
             display.v("diff mode changed to %s" % self.options.diff)
         else:
             display.display("Please specify a diff value , e.g. `diff yes`")
@@ -356,7 +355,7 @@ class ConsoleCLI(CLI, cmd.Cmd):
         if module_name in self.modules:
             in_path = module_loader.find_plugin(module_name)
             if in_path:
-                oc, a, _, _ = module_docs.get_docstring(in_path)
+                oc, a, _, _ = plugin_docs.get_docstring(in_path)
                 if oc:
                     display.display(oc['short_description'])
                     display.display('Parameters:')
@@ -371,7 +370,7 @@ class ConsoleCLI(CLI, cmd.Cmd):
         mline = line.partition(' ')[2]
         offs = len(mline) - len(text)
 
-        if self.options.cwd in ('all','*','\\'):
+        if self.options.cwd in ('all', '*', '\\'):
             completions = self.hosts + self.groups
         else:
             completions = [x.name for x in self.inventory.list_hosts(self.options.cwd)]
@@ -388,16 +387,15 @@ class ConsoleCLI(CLI, cmd.Cmd):
 
     def module_args(self, module_name):
         in_path = module_loader.find_plugin(module_name)
-        oc, a, _, _ = module_docs.get_docstring(in_path)
+        oc, a, _, _ = plugin_docs.get_docstring(in_path)
         return list(oc['options'].keys())
 
     def run(self):
 
         super(ConsoleCLI, self).run()
 
-        sshpass    = None
+        sshpass = None
         becomepass = None
-        vault_pass = None
 
         # hosts
         if len(self.args) != 1:
@@ -414,32 +412,20 @@ class ConsoleCLI(CLI, cmd.Cmd):
 
         self.normalize_become_options()
         (sshpass, becomepass) = self.ask_passwords()
-        self.passwords = { 'conn_pass': sshpass, 'become_pass': becomepass }
+        self.passwords = {'conn_pass': sshpass, 'become_pass': becomepass}
 
-        self.loader = DataLoader()
+        self.loader, self.inventory, self.variable_manager = self._play_prereqs(self.options)
 
-        if self.options.vault_password_file:
-            # read vault_pass from a file
-            vault_pass = CLI.read_vault_password_file(self.options.vault_password_file, loader=self.loader)
-            self.loader.set_vault_password(vault_pass)
-        elif self.options.ask_vault_pass:
-            vault_pass = self.ask_vault_passwords()
-            self.loader.set_vault_password(vault_pass)
+        default_vault_ids = C.DEFAULT_VAULT_IDENTITY_LIST
+        vault_ids = self.options.vault_ids
+        vault_ids = default_vault_ids + vault_ids
+        vault_secrets = self.setup_vault_secrets(self.loader,
+                                                 vault_ids=vault_ids,
+                                                 vault_password_files=self.options.vault_password_files,
+                                                 ask_vault_pass=self.options.ask_vault_pass)
+        self.loader.set_vault_secrets(vault_secrets)
 
-        self.variable_manager = VariableManager()
-        self.inventory = Inventory(loader=self.loader, variable_manager=self.variable_manager, host_list=self.options.inventory)
-        self.variable_manager.set_inventory(self.inventory)
-
-        no_hosts = False
-        if len(self.inventory.list_hosts()) == 0:
-            # Empty inventory
-            no_hosts = True
-            display.warning("provided hosts list is empty, only localhost is available")
-
-        self.inventory.subset(self.options.subset)
-        hosts = self.inventory.list_hosts(self.pattern)
-        if len(hosts) == 0 and not no_hosts:
-            raise AnsibleError("Specified hosts and/or --limit does not match any hosts")
+        hosts = CLI.get_host_list(self.inventory, self.options.subset, self.pattern)
 
         self.groups = self.inventory.list_groups()
         self.hosts = [x.name for x in hosts]
